@@ -47,7 +47,7 @@
 /*
  * Return an integer vector of all the PIDs running on the system.
  */
-SEXP ps__pids() {
+SEXP ps__pids(void) {
   kinfo_proc *proclist = NULL;
   kinfo_proc *orig_address = NULL;
   size_t num_processes;
@@ -84,7 +84,7 @@ SEXP ps__pids() {
   return R_NilValue;
 }
 
-SEXP ps__define_tcp_statuses() {
+SEXP ps__define_tcp_statuses(void) {
   SEXP result, names;
 
   PROTECT(result = allocVector(INTSXP, 12));
