@@ -5,8 +5,9 @@ if (ps::ps_is_supported() && Sys.getenv("R_COVR", "") != "true" &&
     Sys.getenv("NOT_CRAN") != "" ) {
   reporter <- ps::CleanupReporter(testthat::SummaryReporter)$new()
 } else {
-  ## ps does not support this platform
-  reporter <- "progress"
+  reporter <- "summary"
 }
 
-if (ps_is_supported()) test_check("ps", reporter = reporter)
+if (ps_is_supported() && Sys.getenv("NOT_CRAN") != "") {
+  test_check("ps", reporter = reporter)
+}
